Takes the inputs for a Gaussian graphical model and bundles them into
one object, ready for prior elicitation with elicit_prior.
Arguments
- K
A
pbypsymmetric positive-definite precision matrix, .- G
A
pbypsymmetric 0/1 adjacency matrix with zero diagonal.- nu
Prior study size (degrees of freedom).
- mu
Mean vector of length
p. The defaultNULLcorresponds to the centered (zero-mean) case that all current methods assume. Supplying a non-NULLmuis not yet supported.- pip
Prior inclusion probabilities. The default
NULLcorresponds to the uniform prior. Can be a single probability or apbypsymmetric matrix with zero diagonal.