Skip to contents

Simulates prior studies for a model family: data are generated from the family likelihood and the parameters of interest are estimated, generating one bgm_parameters object per study, as if obtained from a previous study. Elicitation is a separate step. What is generated depends on the class of study. See the method pages listed under Details.

Usage

simulate_prior_study(study, n_studies = 1L, ...)

Arguments

study

A bgm_study object, as returned by each family's constructor, for example ggm_study.

n_studies

Number of independent prior studies to simulate. Default 1.

...

Family-specific arguments passed to the method.

Value

A list of n_studies bgm_parameters objects.

Details

Methods are available for the following classes:

ggm_study

Gaussian graphical models