Simulates prior studies for a model family: data are generated
from the family likelihood and the parameters of interest are estimated,
generating one bgm_parameters object per study, as if obtained from a
previous study. Elicitation is a separate step. What is generated
depends on the class of study. See the method pages listed under
Details.
Arguments
- study
A
bgm_studyobject, as returned by each family's constructor, for exampleggm_study.- n_studies
Number of independent prior studies to simulate. Default 1.
- ...
Family-specific arguments passed to the method.
See also
Other prior elicitation:
elicit_prior(),
elicit_prior.ggm_parameters(),
ggm_study(),
simulate_prior_study.ggm_study()